==> humhub-1.2.2.tar.gz: humhub-1.2.2/protected/humhub/messages/it/base.php <==
<?php
return array (
  '<strong>Confirm</strong> Action' => '<strong>Conferma</strong> azione',
  '<strong>Latest</strong> updates' => '<strong>Ultimi</strong> aggiornamenti',
  '<strong>Mail</strong> summary' => 'Sommario <strong>email</strong>',
  'Account settings' => 'Impostazioni account',
  'Administration' => 'Amministrazione',
  'Allow' => 'Consenti',
  'An error occurred while handling your last action. (Handler not found).' => 'Si è verificato un errore durante l\'ultima azione. (Handler non trovato)',
  'An unexpected error occurred while loading the search result.' => 'Si è verificato un errore caricando i risultati ricerca.',
  'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Un errore imprevisto si è verificato. Se si ripete contattare l\'amministratore.',
  'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Un errore del server imprevisto si è verificato. Se si ripete contattare l\'amministratore.',
  'An unknown error occurred while uploading.' => 'Si è verificato un errore imprevisto durante il caricamento.',
  'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Si è verificato un errore imprevisto durante il caricamento. Suggerimento: verifica le impostazioni di upload_max_filesize e post_max_size php.',
  'Back' => 'Indietro',
  'Back to dashboard' => 'Torna al pannello di controllo',
  'Cancel' => 'Annulla',
  'Choose language:' => 'Scegli lingua:',
  'Close' => 'Chiudi',
  'Collapse' => 'Chiudi',
  'Confirm' => 'Conferma',
  'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Il contenuto sorgente dell\'Addon deve essere un\'istanza di HActiveRecordContent o di HActiveRecordContentAddon!',
  'Copy to clipboard' => 'Copia negli appunti',
  'Could not determine content container!' => 'Non posso determinare il contenuto del container!',
  'Could not find content of addon!' => 'Impossibile trovare l\'addon richiesto!',
  'Default' => 'Predefinito',
  'Deny' => 'Rifiuta',
  'Do you really want to perform this action?' => 'Sei sicuro di voler procedere con questa azione?',
  'Error' => 'Errore',
  'Error while running your last action (Invalid request method).' => 'Si è verificato un errore durante l\'ultima azione (Invalid request method).',
  'Error:' => 'Errore:',
  'Expand' => 'Espandi',
  'Info:' => 'Informazioni:',
  'It looks like you may have taken the wrong turn.' => 'Sembrerebbe che tu abbia preso una strada sbagliata.',
  'Language' => 'Lingua',
  'Loading...' => 'Caricamento...',
  'Login' => 'Login',
  'Logo of {appName}' => 'Logo di {appName}',
  'Logout' => 'Esci',
  'Menu' => 'Menu',
  'Module is not enabled on this content container!' => 'Il modulo non è abilitato in questo contenitore!',
  'My profile' => 'Il mio profilo',
  'My profile image' => 'Immagine del mio profilo',
  'New profile image' => 'Nuova immagine profilo',
  'Next' => 'Avanti',
  'No error information given.' => 'Informazione errore mancante.',
  'Oooops...' => 'Oooops...',
  'Open' => 'Apri',
  'Please type at least 3 characters' => 'Prova a digitare almeno 3 caratteri',
  'Profile dropdown' => '',
  'Profile image of {displayName}' => 'Immagine profilo di {displayName}',
  'Profile picture of {displayName}' => 'Immagine profilo di {displayName}',
  'Save' => 'Salva',
  'Saved' => 'Salvato',
  'Search' => 'Cerca',
  'Show less' => 'Mostra meno',
  'Show more' => 'Mostra altro',
  'Some files could not be uploaded:' => 'Alcuni file non possono essere caricati:',
  'Space not found!' => 'Space non trovato!',
  'The date has to be in the past.' => 'La data deve essere nel passato.',
  'The file has been deleted.' => 'Il file è stato cancellato.',
  'The requested resource could not be found.' => 'La risorsa richiesta non è stata trovata.',
  'The space has been archived.' => 'Lo Space è stato archiviato. ',
  'The space has been unarchived.' => 'Lo Space è stato disarchiviato.',
  'Toggle comment menu' => '',
  'Toggle panel menu' => '',
  'Toggle post menu' => '',
  'Toggle stream entry menu' => '',
  'Unsubscribe' => 'Cancella sottoscrizione',
  'Upload' => 'Carica',
  'Upload file' => 'Carica file',
  'User not found!' => 'Utente non trovato!',
  'You are not allowed to run this action.' => 'Non hai i permessi per questa azione.',
);

==> humhub-1.2.8.tar.gz: humhub-1.2.8/protected/humhub/messages/it/base.php <==
<?php
return array (
  '<strong>Confirm</strong> Action' => '<strong>Conferma</strong> azione',
  '<strong>Latest</strong> updates' => '<strong>Ultimi</strong> aggiornamenti',
  '<strong>Mail</strong> summary' => 'Sommario <strong>email</strong>',
  'Account settings' => 'Impostazioni account',
  'Administration' => 'Amministrazione',
  'Allow' => 'Consenti',
  'An error occurred while handling your last action. (Handler not found).' => 'Si è verificato un errore durante l\'ultima azione. (Handler non trovato)',
  'An unexpected error occurred while loading the search result.' => 'Si è verificato un errore caricando i risultati ricerca.',
  'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Un errore imprevisto si è verificato. Se si ripete contattare l\'amministratore.',
  'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Un errore del server imprevisto si è verificato. Se si ripete contattare l\'amministratore.',
  'An unknown error occurred while uploading.' => 'Si è verificato un errore imprevisto durante il caricamento.',
  'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Si è verificato un errore imprevisto durante il caricamento. Suggerimento: verifica le impostazioni di upload_max_filesize e post_max_size php.',
  'Back' => 'Indietro',
  'Back to dashboard' => 'Torna alla bacheca',
  'Cancel' => 'Annulla',
  'Choose language:' => 'Scegli lingua:',
  'Close' => 'Chiudi',
  'Collapse' => 'Chiudi',
  'Confirm' => 'Conferma',
  'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Il contenuto sorgente dell\'Addon deve essere un\'istanza di HActiveRecordContent o di HActiveRecordContentAddon!',
  'Copy to clipboard' => 'Copia negli appunti',
  'Could not determine content container!' => 'Non posso determinare il contenuto del container!',
  'Could not find content of addon!' => 'Impossibile trovare l\'addon richiesto!',
  'Default' => 'Predefinito',
  'Deny' => 'Rifiuta',
  'Do you really want to perform this action?' => 'Sei sicuro di voler procedere con questa azione?',
  'Error' => 'Errore',
  'Error while running your last action (Invalid request method).' => 'Si è verificato un errore durante l\'ultima azione (Invalid request method).',
  'Error:' => 'Errore:',
  'Expand' => 'Espandi',
  'Export' => 'Esporta',
  'Info:' => 'Informazioni:',
  'Invalid request method!' => 'Metodo richiesta non valido!',
  'It looks like you may have taken the wrong turn.' => 'Sembrerebbe che tu abbia preso una strada sbagliata.',
  'Language' => 'Lingua',
  'Loading...' => 'Caricamento...',
  'Login' => 'Login',
  'Logo of {appName}' => 'Logo di {appName}',
  'Logout' => 'Esci',
  'Menu' => 'Menu',
  'Module is not enabled on this content container!' => 'Il modulo non è abilitato in questo contenitore!',
  'My profile' => 'Il mio profilo',
  'My profile image' => 'Immagine del mio profilo',
  'New profile image' => 'Nuova immagine profilo',
  'Next' => 'Avanti',
  'No error information given.' => 'Informazione errore mancante.',
  'Oooops...' => 'Oooops...',
  'Open' => 'Apri',
  'Please type at least 3 characters' => 'Prova a digitare almeno 3 caratteri',
  'Profile dropdown' => 'Diminuzione del profilo',
  'Profile image of {displayName}' => 'Immagine profilo di {displayName}',
  'Profile picture of {displayName}' => 'Immagine profilo di {displayName}',
  'Save' => 'Salva',
  'Saved' => 'Salvato',
  'Search' => 'Cerca',
  'Select Me' => 'Selezionami',
  'Show less' => 'Mostra meno',
  'Show more' => 'Mostra altro',
  'Some files could not be uploaded:' => 'Alcuni file non possono essere caricati:',
  'Space not found!' => 'Space non trovato!',
  'Text could not be copied to clipboard' => 'Il testo non può essere copiato negli appunti',
  'Text has been copied to clipboard' => 'Il testo è stato copiato negli appunti',
  'The date has to be in the past.' => 'La data deve essere nel passato.',
  'The file has been deleted.' => 'Il file è stato cancellato.',
  'The requested resource could not be found.' => 'La risorsa richiesta non è stata trovata.',
  'The space has been archived.' => 'Lo Space è stato archiviato. ',
  'The space has been unarchived.' => 'Lo Space è stato disarchiviato.',
  'Time Zone' => 'Fuso orario',
  'Toggle comment menu' => 'Attiva menu Commento',
  'Toggle panel menu' => 'Attiva menu Pannello',
  'Toggle post menu' => 'Attiva menu Post',
  'Toggle stream entry menu' => 'Attiva  menu Stream',
  'Unsubscribe' => 'Cancella sottoscrizione',
  'Upload' => 'Carica',
  'Upload file' => 'Carica file',
  'User not found!' => 'Utente non trovato!',
  'You are not allowed to run this action.' => 'Non hai i permessi per questa azione.',
);
